Welcome to Ralph Assets's documentation!
========================================

Ralph Assets module brings offline stock management functionality to Ralph.
It maintains placing orders, purchasing and releasing of devices to the users.
It is not limited to the data center. You can maintain inventory of your back
office assets with it as well.
In this module, you can also manage licenses and supports.


Ralph is an asset management system for your data center. It lets you see what
hardware and software is installed. It also lets you keep track of who is using
every device, for what, and how much it costs.

Contents:

.. toctree::
   :maxdepth: 2

   quickstart
   installation
   configuration
   transitions
   history
   regions
   signals
   changes
   license

